@@ -338,7 +338,7 @@ class Game(BaseActivity):
 
     @property
     def type(self):
-        """Returns the game's type. This is for compatibility with :class:`Activity`.
+        """:class:`ActivityType`: Returns the game's type. This is for compatibility with :class:`Activity`.
 
         It always returns :attr:`ActivityType.playing`.
         """
@@ -420,7 +420,7 @@ class Streaming(BaseActivity):
     name: Optional[:class:`str`]
         The stream's name.
     details: Optional[:class:`str`]
-        Same as :attr:`name`
+        An alias for :attr:`name`
     game: Optional[:class:`str`]
         The game being streamed.
 
@@ -445,7 +445,7 @@ class Streaming(BaseActivity):
 
     @property
     def type(self):
-        """Returns the game's type. This is for compatibility with :class:`Activity`.
+        """:class:`ActivityType`: Returns the game's type. This is for compatibility with :class:`Activity`.
 
         It always returns :attr:`ActivityType.streaming`.
         """
@@ -530,7 +530,7 @@ class Spotify:
 
     @property
     def type(self):
-        """Returns the activity's type. This is for compatibility with :class:`Activity`.
+        """:class:`ActivityType`: Returns the activity's type. This is for compatibility with :class:`Activity`.
 
         It always returns :attr:`ActivityType.listening`.
         """
@@ -547,16 +547,16 @@ class Spotify:
 
     @property
     def colour(self):
-        """Returns the Spotify integration colour, as a :class:`Colour`.
+        """:class:`Colour`: Returns the Spotify integration colour, as a :class:`Colour`.
 
-        There is an alias for this named :meth:`color`"""
+        There is an alias for this named :attr:`color`"""
         return Colour(0x1db954)
 
     @property
     def color(self):
-        """Returns the Spotify integration colour, as a :class:`Colour`.
+        """:class:`Colour`: Returns the Spotify integration colour, as a :class:`Colour`.
 
-        There is an alias for this named :meth:`colour`"""
+        There is an alias for this named :attr:`colour`"""
         return self.colour
 
     def to_dict(self):
@@ -697,7 +697,7 @@ class CustomActivity(BaseActivity):
 
     @property
     def type(self):
-        """Returns the activity's type. This is for compatibility with :class:`Activity`.
+        """:class:`ActivityType`: Returns the activity's type. This is for compatibility with :class:`Activity`.
 
         It always returns :attr:`ActivityType.custom`.
         """
